@@ -7,23 +7,22 @@
  *
  * This is free software; you can redistribute and/or modify it under
  * the terms of the GNU Lesser General Public Licence as published
- * by the Free Software Foundation. 
+ * by the Free Software Foundation.
  * See the COPYING file for more information.
  *
  **********************************************************************/
 
-#ifndef GEOS_INDEX_SWEEPLINE_SWEEPLINEOVERLAPACTION_H
-#define GEOS_INDEX_SWEEPLINE_SWEEPLINEOVERLAPACTION_H
+#pragma once
 
 #include <geos/export.h>
 
 // Forward declarations
 namespace geos {
-	namespace index { 
-		namespace sweepline {
-			class SweepLineInterval;
-		}
-	}
+namespace index {
+namespace sweepline {
+class SweepLineInterval;
+}
+}
 }
 
 namespace geos {
@@ -32,9 +31,10 @@ namespace sweepline { // geos:index:sweepline
 
 class GEOS_DLL SweepLineOverlapAction {
 public:
-	virtual void overlap(SweepLineInterval *s0,SweepLineInterval *s1)=0;
+    virtual void overlap(SweepLineInterval* s0, SweepLineInterval* s1) = 0;
 
-	virtual ~SweepLineOverlapAction() {}
+    virtual
+    ~SweepLineOverlapAction() {}
 };
 
 
@@ -42,4 +42,3 @@ public:
 } // namespace geos:index
 } // namespace geos
 
-#endif // GEOS_INDEX_SWEEPLINE_SWEEPLINEOVERLAPACTION_H
