@@ -66,7 +66,7 @@ private:
      */
     void node(std::vector<SegmentString*>* segStrings,
               int& numInteriorIntersections,
-              geom::Coordinate& intersectionPoint);
+              geom::CoordinateXY& intersectionPoint);
 
 public:
 
@@ -104,7 +104,7 @@ public:
 
 
     /** \brief
-     * Fully nodes a list of {@link SegmentString}s, i.e. peforms noding iteratively
+     * Fully nodes a list of {@link SegmentString}s, i.e. performs noding iteratively
      * until no intersections are found between segments.
      *
      * Maintains labelling of edges correctly through the noding.
