@@ -23,8 +23,7 @@
  *
  **********************************************************************/
 
-#ifndef GEOS_OPERATION_SHAREDPATHSOP_H
-#define GEOS_OPERATION_SHAREDPATHSOP_H
+#pragma once
 
 #include <geos/export.h> // for GEOS_DLL
 
@@ -80,12 +79,12 @@ public:
     /// @param sameDirection
     ///   Shared edges having the same direction are pushed
     ///   onto this vector. They'll be of type LineString.
-    ///   Ownership of the edges is tranferred.
+    ///   Ownership of the edges is transferred.
     ///
     /// @param oppositeDirection
     ///   Shared edges having the opposite direction are pushed
     ///   onto this vector. They'll be of type geom::LineString.
-    ///   Ownership of the edges is tranferred.
+    ///   Ownership of the edges is transferred.
     ///
     static void sharedPathsOp(const geom::Geometry& g1,
                               const geom::Geometry& g2,
@@ -107,12 +106,12 @@ public:
     /// @param sameDirection
     ///   Shared edges having the same direction are pushed
     ///   onto this vector. They'll be of type geom::LineString.
-    ///   Ownership of the edges is tranferred.
+    ///   Ownership of the edges is transferred.
     ///
     /// @param oppositeDirection
     ///   Shared edges having the opposite direction are pushed
     ///   onto this vector. They'll be of type geom::LineString.
-    ///   Ownership of the edges is tranferred.
+    ///   Ownership of the edges is transferred.
     ///
     void getSharedPaths(PathList& sameDirection, PathList& oppositeDirection);
 
@@ -160,6 +159,3 @@ private:
 } // namespace geos.operation.sharedpaths
 } // namespace geos.operation
 } // namespace geos
-
-#endif
-
