@@ -28,6 +28,8 @@
 #include <algorithm>
 #include <limits>
 #include <iostream>
+
+#include "geos/util.h"
 using namespace geos::geom;
 
 namespace geos {
@@ -142,6 +144,9 @@ DiscreteFrechetDistance::compute(
         throw util::IllegalArgumentException("DiscreteFrechetDistance called with empty inputs.");
     }
 
+    util::ensureNoCurvedComponents(discreteGeom);
+    util::ensureNoCurvedComponents(geom);
+
     auto lp = discreteGeom.getCoordinates();
     auto lq = geom.getCoordinates();
     std::size_t pSize, qSize;
