@@ -19,20 +19,9 @@
 #include <geos/noding/BasicSegmentString.h>
 #include <geos/geom/CoordinateSequence.h>
 
-#ifndef GEOS_INLINE
-# include <geos/noding/BasicSegmentString.inl>
-#endif
-
-#ifndef GEOS_DEBUG
-#define GEOS_DEBUG 0
-#endif
-
 #include <iostream>
 #include <sstream>
 
-using namespace geos::algorithm;
-using namespace geos::geom;
-
 namespace geos {
 namespace noding { // geos.noding
 
@@ -41,7 +30,7 @@ std::ostream&
 BasicSegmentString::print(std::ostream& os) const
 {
     os << "BasicSegmentString: " << std::endl;
-    os << " LINESTRING" << *(pts) << ";" << std::endl;
+    os << " LINESTRING" << *(getCoordinates()) << ";" << std::endl;
 
     return os;
 }
