@@ -20,10 +20,10 @@
 #include <geos/operation/overlay/validate/FuzzyPointLocator.h>
 #include <geos/operation/overlay/validate/OffsetPointGenerator.h>
 #include <geos/operation/overlay/snap/GeometrySnapper.h>
+#include <geos/operation/overlayng/OverlayNG.h>
 #include <geos/geom/CoordinateSequence.h>
 #include <geos/geom/MultiPoint.h>
 #include <geos/geom/GeometryFactory.h>
-#include <geos/geom/CoordinateSequenceFactory.h>
 
 #include <cassert>
 #include <functional>
@@ -46,7 +46,6 @@
 
 
 using namespace geos::geom;
-using namespace geos::geomgraph;
 using namespace geos::algorithm;
 
 namespace geos {
@@ -54,32 +53,11 @@ namespace operation { // geos.operation
 namespace overlay { // geos.operation.overlay
 namespace validate { // geos.operation.overlay.validate
 
-namespace { // anonymous namespace
-
-#if GEOS_DEBUG
-std::unique_ptr<MultiPoint>
-toMultiPoint(std::vector<Coordinate>& coords)
-{
-    const GeometryFactory& gf = *(GeometryFactory::getDefaultInstance());
-    const CoordinateSequenceFactory& csf =
-        *(gf.getCoordinateSequenceFactory());
-
-    std::unique_ptr< std::vector<Coordinate> > nc(new std::vector<Coordinate>(coords));
-    std::unique_ptr<CoordinateSequence> cs(csf.create(nc.release()));
-
-    std::unique_ptr<MultiPoint> mp(gf.createMultiPoint(*cs));
-
-    return mp;
-}
-#endif
-
-} // anonymous namespace
-
 
 /* static public */
 bool
 OverlayResultValidator::isValid(const Geometry& geom0, const Geometry& geom1,
-                                OverlayOp::OpCode opCode,
+                                int opCode,
                                 const Geometry& result)
 {
     OverlayResultValidator validator(geom0, geom1, result);
@@ -107,7 +85,7 @@ OverlayResultValidator::OverlayResultValidator(
 
 /*public*/
 bool
-OverlayResultValidator::isValid(OverlayOp::OpCode overlayOp)
+OverlayResultValidator::isValid(int overlayOp)
 {
 
     addTestPts(g0);
@@ -115,15 +93,6 @@ OverlayResultValidator::isValid(OverlayOp::OpCode overlayOp)
     addTestPts(gres);
 
     if(! testValid(overlayOp)) {
-#if GEOS_DEBUG
-        std::cerr << "OverlayResultValidator:" << std::endl
-             << "Points:" << *toMultiPoint(testCoords) << std::endl
-             << "Geom0: " << g0 << std::endl
-             << "Geom1: " << g1 << std::endl
-             << "Reslt: " << gres << std::endl
-             << "Locat: " << getInvalidLocation()
-             << std::endl;
-#endif
         return false;
     }
 
@@ -156,7 +125,7 @@ OverlayResultValidator::addVertices(const Geometry& g)
 
 /*private*/
 bool
-OverlayResultValidator::testValid(OverlayOp::OpCode overlayOp)
+OverlayResultValidator::testValid(int overlayOp)
 {
     for(std::size_t i = 0, n = testCoords.size(); i < n; ++i) {
         Coordinate& pt = testCoords[i];
@@ -170,7 +139,7 @@ OverlayResultValidator::testValid(OverlayOp::OpCode overlayOp)
 
 /*private*/
 bool
-OverlayResultValidator::testValid(OverlayOp::OpCode overlayOp,
+OverlayResultValidator::testValid(int overlayOp,
                                   const Coordinate& pt)
 {
     // TODO use std::array<geom::Location, 3> ?
@@ -204,11 +173,11 @@ OverlayResultValidator::testValid(OverlayOp::OpCode overlayOp,
 
 /* private */
 bool
-OverlayResultValidator::isValidResult(OverlayOp::OpCode overlayOp,
+OverlayResultValidator::isValidResult(int overlayOp,
                                       std::vector<geom::Location>& location)
 {
-    bool expectedInterior = OverlayOp::isResultOfOp(location[0],
-                            location[1], overlayOp);
+    bool expectedInterior = overlayng::OverlayNG::isResultOfOp(overlayOp, location[0],
+                            location[1]);
 
     bool resultInInterior = (location[2] == Location::INTERIOR);
 
