@@ -34,11 +34,10 @@ template<>
 template<>
 void object::test<1>()
 {
-    input_ = GEOSGeomFromWKT("POLYGON EMPTY");
-    ensure(nullptr != input_);
+    input_ = fromWKT("POLYGON EMPTY");
     geom1_ = GEOSConcaveHullOfPolygons(input_, 0.7, false, false);
     ensure(nullptr != geom1_);
-    expected_ = GEOSGeomFromWKT("POLYGON EMPTY");
+    expected_ = fromWKT("POLYGON EMPTY");
     ensure_geometry_equals(geom1_, expected_);
 }
 
@@ -46,14 +45,33 @@ template<>
 template<>
 void object::test<2>()
 {
-    input_ = GEOSGeomFromWKT("MULTIPOLYGON(((0 0, 0 1, 1 1, 1 0, 0 0)))");
-    ensure(nullptr != input_);
+    input_ = fromWKT("MULTIPOLYGON(((0 0, 0 1, 1 1, 1 0, 0 0)))");
     geom1_ = GEOSConcaveHullOfPolygons(input_, 0.7, false, false);
     ensure(nullptr != geom1_);
-    expected_ = GEOSGeomFromWKT("MULTIPOLYGON(((0 0, 0 1, 1 1, 1 0, 0 0)))");
+    expected_ = fromWKT("MULTIPOLYGON(((0 0, 0 1, 1 1, 1 0, 0 0)))");
     ensure_geometry_equals(geom1_, expected_);
 }
 
+template<>
+template<>
+void object::test<3>()
+{
+    input_ = fromWKT("CURVEPOLYGON (COMPOUNDCURVE( CIRCULARSTRING (0 0, 1 1, 2 0), (2 0, 0 0) ))");
+    ensure(input_ != nullptr);
+
+    result_ = GEOSConcaveHullOfPolygons(input_, 0.7, false, false);
+    ensure("curved geometry not supported", result_ == nullptr);
+}
+  
+template<>
+template<>
+void object::test<4>()
+{
+    input_ = fromWKT("POLYGON((0 0, 0 0, 0 0))");
+    result_ = GEOSConcaveHullOfPolygons(input_, 0.7, false, false);
+    ensure(GEOSisEmpty(result_));
+}
+
 
 } // namespace tut
 
