@@ -152,7 +152,7 @@ void object::test<3>
     ensure_equals(zcheck, z);
 
     // correct error on wrong ordinate index
-    ensure(0 == GEOSCoordSeq_setOrdinate(cs_, 0, 3, z));
+    ensure(0 == GEOSCoordSeq_setOrdinate(cs_, 0, 37, z));
 }
 
 // Test swapped setX calls (see bug #133, fixed)
@@ -319,7 +319,8 @@ void object::test<9>
     GEOSCoordSeq_setX(cs_, 2, 1);
     GEOSCoordSeq_setY(cs_, 2, 0);
 
-    ensure_equals(GEOSCoordSeq_isCCW(cs_, &ccw), 0);
+    ensure_equals(GEOSCoordSeq_isCCW(cs_, &ccw), 1);
+    ensure(!ccw);
 }
 
 template<>
@@ -331,7 +332,8 @@ void object::test<10>
     cs_ = GEOSCoordSeq_create(0, 0);
     char ccw;
 
-    ensure_equals(GEOSCoordSeq_isCCW(cs_, &ccw), 0);
+    ensure_equals(GEOSCoordSeq_isCCW(cs_, &ccw), 1);
+    ensure(!ccw);
 }
 
 template<>
@@ -345,10 +347,10 @@ void object::test<11>
     unsigned int dims;
 
     ensure(0 != GEOSCoordSeq_getSize(cs_, &size));
-    ensure_equals(size, 1u);
+    ensure_equals("Seq has expected size", size, 1u);
 
     ensure(0 != GEOSCoordSeq_getDimensions(cs_, &dims));
-    ensure_equals(dims, 2u);
+    ensure_equals("seq has expected dim", dims, 2u);
 
     double x = 10;
     double y = 11;
@@ -361,12 +363,14 @@ void object::test<11>
     ensure_equals(xcheck, x);
     ensure_equals(ycheck, y);
 
+    // Calling getXYZ on a 2D seq gets you NaN for Z
     ensure(0 != GEOSCoordSeq_getXYZ(cs_, 0, &xcheck, &ycheck, &zcheck));
 
     ensure_equals(xcheck, x);
     ensure_equals(ycheck, y);
-    ensure(std::isnan(zcheck));
+    ensure("z is NaN on 2D seq", std::isnan(zcheck));
 
+    // Calling setXYZ on a 2D seq coerces to 3D
     double z = 12;
     GEOSCoordSeq_setXYZ(cs_, 0, x, y, z);
 
@@ -417,46 +421,60 @@ void object::test<12>()
 }
 
 // test 3D from/to buffer
-    template<>
-    template<>
-    void object::test<13>()
-    {
-        unsigned int N = 10;
-        unsigned int dim = 3;
-        std::vector<double> values(N * dim);
-        for (size_t i = 0; i < values.size(); i++) {
-            values[i] = static_cast<double>(i);
-        }
-
-        cs_ = GEOSCoordSeq_copyFromBuffer(values.data(), N, true, false);
-
-        double x, y, z;
-        ensure(GEOSCoordSeq_getXYZ(cs_, 0, &x, &y, &z));
-        ensure_equals(x, 0.0);
-        ensure_equals(y, 1.0);
-        ensure_equals(z, 2.0);
-
-        ensure(GEOSCoordSeq_getXYZ(cs_, N - 1, &x, &y, &z));
-        ensure_equals(x, static_cast<double>(N-1)*3);
-        ensure_equals(y, static_cast<double>(N-1)*3 + 1);
-        ensure_equals(z, static_cast<double>(N-1)*3 + 2);
-
-        unsigned int dim_out;
-        ensure(GEOSCoordSeq_getDimensions(cs_, &dim_out));
-        ensure_equals(dim_out, dim);
-
-        std::vector<double> out3(N * 3);
-        ensure(GEOSCoordSeq_copyToBuffer(cs_, out3.data(), true, false));
-        ensure(out3 == values);
-
-        std::vector<double> out2(N * 2);
-        ensure(GEOSCoordSeq_copyToBuffer(cs_, out2.data(), false, false));
-        ensure_equals(out2[0], values[0]); // X1
-        ensure_equals(out2[1], values[1]); // Y1
-        ensure_equals(out2[2], values[3]); // X2
-        ensure_equals(out2[3], values[4]); // Y2
+template<>
+template<>
+void object::test<13>()
+{
+    unsigned int N = 10;
+    unsigned int dim = 3;
+    std::vector<double> values(N * dim);
+    for (size_t i = 0; i < values.size(); i++) {
+        values[i] = static_cast<double>(i);
     }
 
+    cs_ = GEOSCoordSeq_copyFromBuffer(values.data(), N, true, false);
+
+    double x, y, z;
+    ensure(GEOSCoordSeq_getXYZ(cs_, 0, &x, &y, &z));
+    ensure_equals(x, 0.0);
+    ensure_equals(y, 1.0);
+    ensure_equals(z, 2.0);
+
+    ensure(GEOSCoordSeq_getXYZ(cs_, N - 1, &x, &y, &z));
+    ensure_equals(x, static_cast<double>(N-1)*3);
+    ensure_equals(y, static_cast<double>(N-1)*3 + 1);
+    ensure_equals(z, static_cast<double>(N-1)*3 + 2);
+
+    unsigned int dim_out;
+    ensure(GEOSCoordSeq_getDimensions(cs_, &dim_out));
+    ensure_equals(dim_out, dim);
+
+    std::vector<double> out3(N * 3);
+    ensure(GEOSCoordSeq_copyToBuffer(cs_, out3.data(), true, false));
+    ensure(out3 == values);
+
+    // Copy to 2D buffer
+    std::vector<double> out2(N * 2);
+    ensure(GEOSCoordSeq_copyToBuffer(cs_, out2.data(), false, false));
+    ensure_equals(out2[0], values[0]); // X1
+    ensure_equals(out2[1], values[1]); // Y1
+    ensure_equals(out2[2], values[3]); // X2
+    ensure_equals(out2[3], values[4]); // Y2
+
+    // Copy to XYZM buffer
+    std::vector<double> out4(N * 4);
+    ensure(GEOSCoordSeq_copyToBuffer(cs_, out4.data(), true, true));
+    for (size_t i = 0, j = 0; i < out4.size(); i++) {
+        if (i % 4 == 3) {
+            // M should be set to NaN
+            ensure(std::isnan(out4[i]));
+        } else {
+            // XYZ should be copied in
+            ensure_equals(out4[i], values[j++]);
+        }
+    }
+}
+
 // test 2D from/to arrays
 template<>
 template<>
@@ -564,10 +582,10 @@ void object::test<16>()
 
     cs_ = GEOSCoordSeq_copyFromBuffer(values.data(), N, false, true);
 
-    // XYM buffer produces 2D coordinate sequence
+    // XYM buffer produces 3D coordinate sequence
     unsigned int dim_out;
     ensure(GEOSCoordSeq_getDimensions(cs_, &dim_out));
-    ensure_equals(dim_out, 2u);
+    ensure_equals(dim_out, 3u);
 
     // Check first coordinate
     double x, y, z;
@@ -589,9 +607,16 @@ void object::test<16>()
     ensure_equals(out2[1], values[1]); // Y1
     ensure_equals(out2[2], values[3]); // X2
     ensure_equals(out2[3], values[4]); // Y2
+
+    // Copy to XYM buffer
+    std::vector<double> out3m(N * 3);
+    ensure(GEOSCoordSeq_copyToBuffer(cs_, out3m.data(), false, true));
+    for (size_t i =0; i < values.size(); i++) {
+        ensure_equals(out3m[i], values[i]);
+    }
 }
 
-// test 3DZM from/to buffer
+// test 4D from/to buffer
 template<>
 template<>
 void object::test<17>()
@@ -605,10 +630,10 @@ void object::test<17>()
 
     cs_ = GEOSCoordSeq_copyFromBuffer(values.data(), N, true, true);
 
-    // XYZM buffer creates a 3D coordinate sequence
+    // XYZM buffer creates a 4D coordinate sequence
     unsigned int dim_out;
     ensure(GEOSCoordSeq_getDimensions(cs_, &dim_out));
-    ensure_equals(dim_out, 3u);
+    ensure_equals(dim_out, 4u);
 
     // Check first coordinate
     double x, y, z;
@@ -624,16 +649,121 @@ void object::test<17>()
     ensure_equals(z, static_cast<double>(N-1)*4 + 2);
 
     // Copy to 4D buffer
-    std::vector<double> out2(N * 4);
-    ensure(GEOSCoordSeq_copyToBuffer(cs_, out2.data(), true, true));
-    ensure_equals(out2[0], values[0]); // X1
-    ensure_equals(out2[1], values[1]); // Y1
-    ensure_equals(out2[2], values[2]); // Z1
-    ensure(std::isnan(out2[3]));
-    ensure_equals(out2[4], values[4]); // X2
-    ensure_equals(out2[5], values[5]); // Y2
-    ensure_equals(out2[6], values[6]); // Z2
+    std::vector<double> out4d(N * 4);
+    ensure(GEOSCoordSeq_copyToBuffer(cs_, out4d.data(), true, true));
+    ensure_equals("X1", out4d[0], values[0]);
+    ensure_equals("Y1", out4d[1], values[1]);
+    ensure_equals("Z1", out4d[2], values[2]);
+    ensure_equals("M1", out4d[3], values[3]);
+    ensure_equals("X2", out4d[4], values[4]);
+    ensure_equals("Y2", out4d[5], values[5]);
+    ensure_equals("Z2", out4d[6], values[6]);
+    ensure_equals("M2", out4d[7], values[7]);
+
+    // Copy to XYZ buffer
+    std::vector<double> out3d(N * 3);
+    ensure(GEOSCoordSeq_copyToBuffer(cs_, out3d.data(), true, false));
+    ensure_equals("X1", out3d[0], values[0]);
+    ensure_equals("Y1", out3d[1], values[1]);
+    ensure_equals("Z1", out3d[2], values[2]);
+    ensure_equals("X2", out3d[3], values[4]);
+    ensure_equals("Y2", out3d[4], values[5]);
+    ensure_equals("Z2", out3d[5], values[6]);
+}
+
+// test error on invalid dim
+template<>
+template<>
+void object::test<18>()
+{
+    ensure(!GEOSCoordSeq_create(0, 1));
+    ensure(!GEOSCoordSeq_create(0, 5));
+}
+
+// test 3d values stored correctly in 4D seq
+template<>
+template<>
+void object::test<19>()
+{
+    cs_ = GEOSCoordSeq_create(2, 4);
+    GEOSCoordSeq_setXYZ(cs_, 0, 1, 2, 3);
+    GEOSCoordSeq_setXYZ(cs_, 1, 4, 5, 6);
+
+    double x, y, z;
+    GEOSCoordSeq_getXYZ(cs_, 0, &x, &y, &z);
+    ensure_equals(x, 1);
+    ensure_equals(y, 2);
+    ensure_equals(z, 3);
+
+    GEOSCoordSeq_getXYZ(cs_, 1, &x, &y, &z);
+    ensure_equals(x, 4);
+    ensure_equals(y, 5);
+    ensure_equals(z, 6);
+}
+
+// test 3DM from/to arrays
+template<>
+template<>
+void object::test<20>()
+{
+    unsigned int N = 10;
+    std::vector<double> x(N);
+    std::vector<double> y(N);
+    std::vector<double> m(N);
+    for (size_t i = 0; i < N; i++) {
+        x[i] = static_cast<double>(i);
+        y[i] = static_cast<double>(2 * i);
+        m[i] = static_cast<double>(3 * i);
+    }
+
+    cs_ = GEOSCoordSeq_copyFromArrays(x.data(), y.data(), nullptr, m.data(), N);
+    unsigned int dim_out;
+    ensure(GEOSCoordSeq_getDimensions(cs_, &dim_out));
+    ensure_equals("XYM sequence has dimension = 3", dim_out, 3u);
+
+    std::vector<double> xout(N), yout(N), zout(N), mout(N);
+    ensure(GEOSCoordSeq_copyToArrays(cs_, xout.data(), yout.data(), nullptr, mout.data()));
+    ensure(x == xout);
+    ensure(y == yout);
+    ensure(m == mout);
+
+    ensure(GEOSCoordSeq_copyToArrays(cs_, xout.data(), yout.data(), zout.data(), mout.data()));
+    ensure(x == xout);
+    ensure(y == yout);
+    ensure(std::all_of(zout.begin(), zout.end(), [](double zval) { return std::isnan(zval); }));
+    ensure(m == mout);
+}
+
+template<>
+template<>
+void object::test<21>()
+{
+    GEOSContextHandle_t handle = GEOS_init_r();
+
+    const unsigned int sz = 5;
+    GEOSCoordSequence* seq1 = GEOSCoordSeq_create_r(handle, sz, 3);
+    for (unsigned int i = 0; i < sz; i++)  {
+        ensure(GEOSCoordSeq_setX_r(handle, seq1, i, (double) i + 1.0));
+        ensure(GEOSCoordSeq_setY_r(handle, seq1, i, (double) i + 1.0));
+        ensure(GEOSCoordSeq_setZ_r(handle, seq1, i, (double) i + 1.0));
+    }
+
+    GEOSCoordSequence* seq2 = GEOSCoordSeq_clone_r(handle, seq1);
+    for (unsigned int i = 0; i < sz; i++)  {
+        double x, y, z;
+        ensure(GEOSCoordSeq_getX_r(handle, seq2, i, &x));
+        ensure(GEOSCoordSeq_getY_r(handle, seq2, i, &y));
+        ensure(GEOSCoordSeq_getZ_r(handle, seq2, i, &z));
+
+        ensure_equals(x, (double) i + 1.0);
+        ensure_equals(y, (double) i + 1.0);
+        ensure_equals(z, (double) i + 1.0);
+    }
+
+    GEOSCoordSeq_destroy_r(handle, seq1);
+    GEOSCoordSeq_destroy_r(handle, seq2);
+
+    GEOS_finish_r(handle);
 }
 
 } // namespace tut
-
