@@ -38,7 +38,7 @@ template<>
 void object::test<1>
 ()
 {
-    geom1_ = GEOSGeomFromWKT("POLYGON EMPTY");
+    geom1_ = fromWKT("POLYGON EMPTY");
 
     ensure_equals(GEOSisEmpty(geom1_), 1);
 
@@ -47,69 +47,54 @@ void object::test<1>
     ensure_equals(GEOSisEmpty(geom2_), 1);
     ensure_equals(GEOSGeomTypeId(geom2_), GEOS_GEOMETRYCOLLECTION);
 
-    GEOSGeom_destroy(geom2_);
-    geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
-    ensure_equals(GEOSisEmpty(geom2_), 1);
-    ensure_equals(GEOSGeomTypeId(geom2_), GEOS_MULTILINESTRING);
-
-
+    geom3_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
+    ensure_equals(GEOSisEmpty(geom3_), 1);
+    ensure_equals(GEOSGeomTypeId(geom3_), GEOS_MULTILINESTRING);
 }
 
 // Single point
 template<>
 template<>
-void object::test<2>
-()
+void object::test<2>()
 {
-    geom1_ = GEOSGeomFromWKT("POINT(0 0)");
+    geom1_ = fromWKT("POINT(0 0)");
 
     geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 0);
     ensure_equals(GEOSisEmpty(geom2_), 1);
     ensure_equals(GEOSGeomTypeId(geom2_), GEOS_GEOMETRYCOLLECTION);
 
-    GEOSGeom_destroy(geom2_);
-    geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
-    ensure_equals(GEOSisEmpty(geom2_), 1);
-    ensure_equals(GEOSGeomTypeId(geom2_), GEOS_MULTILINESTRING);
+    geom3_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
+    ensure_equals(GEOSisEmpty(geom3_), 1);
+    ensure_equals(GEOSGeomTypeId(geom3_), GEOS_MULTILINESTRING);
 }
 
 // Three collinear points
 template<>
 template<>
-void object::test<3>
-()
+void object::test<3>()
 {
-    geom1_ = GEOSGeomFromWKT("MULTIPOINT((0 0), (5 0), (10 0))");
+    geom1_ = fromWKT("MULTIPOINT((0 0), (5 0), (10 0))");
 
     geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 0);
     ensure_equals(GEOSisEmpty(geom2_), 1);
     ensure_equals(GEOSGeomTypeId(geom2_), GEOS_GEOMETRYCOLLECTION);
 
-    GEOSGeom_destroy(geom2_);
-    geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
-    char* wkt_c = GEOSWKTWriter_write(wktw_, geom2_);
-    std::string out(wkt_c);
-    free(wkt_c);
-    ensure_equals(out, "MULTILINESTRING ((5 0, 10 0), (0 0, 5 0))");
+    geom3_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
+    ensure_geometry_equals(geom3_, "MULTILINESTRING ((5 0, 10 0), (0 0, 5 0))");
 }
 
 // Three points
 template<>
 template<>
-void object::test<4>
-()
+void object::test<4>()
 {
-    geom1_ = GEOSGeomFromWKT("MULTIPOINT((0 0), (5 0), (10 10))");
-
+    geom1_ = fromWKT("MULTIPOINT((0 0), (5 0), (10 10))");
     geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 0);
     ensure(geom2_ != nullptr);
-    ensure_geometry_equals(geom2_,
-                      "GEOMETRYCOLLECTION (POLYGON ((0 0, 10 10, 5 0, 0 0)))");
+    ensure_geometry_equals(geom2_, "GEOMETRYCOLLECTION (POLYGON ((0 0, 10 10, 5 0, 0 0)))");
 
-    GEOSGeom_destroy(geom2_);
-    geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
-    ensure_geometry_equals(geom2_,
-                      "MULTILINESTRING ((5 0, 10 10), (0 0, 10 10), (0 0, 5 0))");
+    geom3_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
+    ensure_geometry_equals(geom3_, "MULTILINESTRING ((5 0, 10 10), (0 0, 10 10), (0 0, 5 0))");
 }
 
 // A polygon with a hole
@@ -118,16 +103,15 @@ template<>
 void object::test<5>
 ()
 {
-    geom1_ = GEOSGeomFromWKT("POLYGON((0 0, 8.5 1, 10 10, 0.5 9, 0 0),(2 2, 3 8, 7 8, 8 2, 2 2))");
+    geom1_ = fromWKT("POLYGON((0 0, 8.5 1, 10 10, 0.5 9, 0 0),(2 2, 3 8, 7 8, 8 2, 2 2))");
 
     geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 0);
     ensure(geom2_ != nullptr);
     ensure_geometry_equals(geom2_,
                       "GEOMETRYCOLLECTION (POLYGON ((8 2, 10 10, 8.5 1, 8 2)), POLYGON ((7 8, 10 10, 8 2, 7 8)), POLYGON ((3 8, 10 10, 7 8, 3 8)), POLYGON ((2 2, 8 2, 8.5 1, 2 2)), POLYGON ((2 2, 7 8, 8 2, 2 2)), POLYGON ((2 2, 3 8, 7 8, 2 2)), POLYGON ((0.5 9, 10 10, 3 8, 0.5 9)), POLYGON ((0.5 9, 3 8, 2 2, 0.5 9)), POLYGON ((0 0, 2 2, 8.5 1, 0 0)), POLYGON ((0 0, 0.5 9, 2 2, 0 0)))");
 
-    GEOSGeom_destroy(geom2_);
-    geom2_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
-    ensure_geometry_equals(geom2_,
+    geom3_ = GEOSDelaunayTriangulation(geom1_, 0, 1);
+    ensure_geometry_equals(geom3_,
                       "MULTILINESTRING ((8.5 1, 10 10), (8 2, 10 10), (8 2, 8.5 1), (7 8, 10 10), (7 8, 8 2), (3 8, 10 10), (3 8, 7 8), (2 2, 8.5 1), (2 2, 8 2), (2 2, 7 8), (2 2, 3 8), (0.5 9, 10 10), (0.5 9, 3 8), (0.5 9, 2 2), (0 0, 8.5 1), (0 0, 2 2), (0 0, 0.5 9))");
 }
 
@@ -137,13 +121,23 @@ template<>
 void object::test<6>
 ()
 {
-    geom1_ = GEOSGeomFromWKT("MULTIPOINT((0 0), (10 0), (10 10), (11 10))");
+    geom1_ = fromWKT("MULTIPOINT((0 0), (10 0), (10 10), (11 10))");
 
-    GEOSGeom_destroy(geom2_);
     geom2_ = GEOSDelaunayTriangulation(geom1_, 2, 1);
     ensure_geometry_equals(geom2_,
                       "MULTILINESTRING ((10 0, 10 10), (0 0, 10 10), (0 0, 10 0))");
 }
 
+template<>
+template<>
+void object::test<7>()
+{
+    input_ = fromWKT("CIRCULARSTRING (0 0, 1 1, 2 0, 3 -1, 4 0)");
+    ensure(input_);
+
+    result_ = GEOSDelaunayTriangulation(input_, 0, 0);
+    ensure("curved geometry not supported", result_ == nullptr);
+}
+
 } // namespace tut
 
