@@ -21,41 +21,43 @@ group test_capigeosgeom_extent_group("capi::GEOSGeom_extent");
 
 template<>
 template<>
-void object::test<1>
-()
+void object::test<1>()
 {
-    GEOSGeometry* g = GEOSGeomFromWKT("LINESTRING (3 8, -12 -4)");
+    geom1_ = fromWKT("LINESTRING (3 8, -12 -4)");
 
     double xmin, ymin, xmax, ymax;
 
-    ensure(GEOSGeom_getXMin(g, &xmin) != 0);
-    ensure(GEOSGeom_getYMin(g, &ymin) != 0);
-    ensure(GEOSGeom_getXMax(g, &xmax) != 0);
-    ensure(GEOSGeom_getYMax(g, &ymax) != 0);
+    ensure(GEOSGeom_getXMin(geom1_, &xmin) != 0);
+    ensure(GEOSGeom_getYMin(geom1_, &ymin) != 0);
+    ensure(GEOSGeom_getXMax(geom1_, &xmax) != 0);
+    ensure(GEOSGeom_getYMax(geom1_, &ymax) != 0);
 
     ensure_equals(xmin, -12);
     ensure_equals(xmax, 3);
     ensure_equals(ymin, -4);
     ensure_equals(ymax, 8);
 
-    GEOSGeom_destroy(g);
+    ensure(GEOSGeom_getExtent(geom1_, &xmin, &ymin, &xmax, &ymax) != 0);
+
+    ensure_equals(xmin, -12);
+    ensure_equals(xmax, 3);
+    ensure_equals(ymin, -4);
+    ensure_equals(ymax, 8);
 }
 
 template<>
 template<>
-void object::test<2>
-()
+void object::test<2>()
 {
-    GEOSGeometry* g = GEOSGeomFromWKT("POLYGON EMPTY");
-
     double d;
+    geom1_ = fromWKT("POLYGON EMPTY");
 
-    ensure_equals(GEOSGeom_getXMax(g, &d), 0);
-    ensure_equals(GEOSGeom_getYMax(g, &d), 0);
-    ensure_equals(GEOSGeom_getXMin(g, &d), 0);
-    ensure_equals(GEOSGeom_getYMin(g, &d), 0);
+    ensure_equals(GEOSGeom_getXMax(geom1_, &d), 0);
+    ensure_equals(GEOSGeom_getYMax(geom1_, &d), 0);
+    ensure_equals(GEOSGeom_getXMin(geom1_, &d), 0);
+    ensure_equals(GEOSGeom_getYMin(geom1_, &d), 0);
 
-    GEOSGeom_destroy(g);
+    ensure_equals(GEOSGeom_getExtent(geom1_, &d, &d, &d, &d), 0);
 }
 
 } // namespace tut
