@@ -21,17 +21,35 @@ template<>
 void object::test<1>
 ()
 {
-    GEOSGeometry* point = GEOSGeomFromWKT("POINT (4 2 7)");
-    GEOSGeometry* line = GEOSGeomFromWKT("LINESTRING (4 2 7 1, 8 2 9 5)");
-    GEOSGeometry* poly = GEOSGeomFromWKT("POLYGON ((0 0, 1 0, 1 1, 0 0))");
+    input_ = fromWKT("POLYGON ((0 0, 1 0, 1 1, 0 0))");
+    ensure_equals(GEOSGeom_getCoordinateDimension(input_), 2);
+}
 
-    ensure_equals(GEOSGeom_getCoordinateDimension(point), 3);
-    ensure_equals(GEOSGeom_getCoordinateDimension(line), 4);
-    ensure_equals(GEOSGeom_getCoordinateDimension(poly), 2);
+template<>
+template<>
+void object::test<2>
+()
+{
+    input_ = fromWKT("POINT (4 2 7)");
+    ensure_equals(GEOSGeom_getCoordinateDimension(input_), 3);
+}
 
-    GEOSGeom_destroy(point);
-    GEOSGeom_destroy(line);
-    GEOSGeom_destroy(poly);
+template<>
+template<>
+void object::test<3>
+()
+{
+    input_ = fromWKT("LINESTRING (4 2 7 1, 8 2 9 5)");
+    ensure_equals(GEOSGeom_getCoordinateDimension(input_), 4);
+}
+
+template<>
+template<>
+void object::test<4>
+()
+{
+    input_ = fromWKT("CIRCULARSTRING Z (0 0 0, 1 1 1, 2 0 2)");
+    ensure_equals(GEOSGeom_getCoordinateDimension(input_), 3);
 }
 
 } // namespace tut
