@@ -259,5 +259,17 @@ void object::test<12>()
         );
 }
 
+template<>
+template<>
+void object::test<13>()
+{
+    input_ = fromWKT("CIRCULARSTRING (0 0, 1 1, 2 0)");
+    ensure(input_);
+
+    result_ = GEOSOffsetCurve(input_, 1, 8, GEOSBUF_JOIN_ROUND, 0);
+
+    ensure("curved geometries not supported", result_ == nullptr);
+}
+
 } // namespace tut
 
