@@ -78,5 +78,18 @@ void object::test<5>
     ensure_equals(ret, char(0));
 }
 
+// invalid DE-9IM argument
+// https://github.com/libgeos/geos/issues/1084
+template<>
+template<>
+void object::test<6>
+()
+{
+    const char* mat = "0000000000";
+    ensure_equals(strlen(mat), 10u); // not a valid DE-9IM!
+
+    GEOSRelatePatternMatch(mat,  "111111111");
+}
+
 } // namespace tut
 
