@@ -21,8 +21,6 @@ namespace tut {
 struct test_capiunaryunionprec_data : public capitest::utility {
 
     test_capiunaryunionprec_data() {
-        GEOSWKTWriter_setTrim(wktw_, 1);
-        GEOSWKTWriter_setOutputDimension(wktw_, 3);
     }
 
 };
@@ -43,14 +41,14 @@ template<>
 void object::test<1>
 ()
 {
-    geom1_ = GEOSGeomFromWKT("MULTIPOINT (4 5, 6 7, 4 5, 6 5, 6 7)");
+    geom1_ = GEOSGeomFromWKT("MULTIPOINT ((4 5), (6 7), (4 5), (6 5), (6 7))");
     ensure(nullptr != geom1_);
 
     geom2_ = GEOSUnaryUnionPrec(geom1_, 2);
     ensure(nullptr != geom2_);
 
-    ensure_equals(toWKT(geom2_), std::string("MULTIPOINT (4 6, 6 6, 6 8)"));
+    ensure_equals(toWKT(geom2_), std::string("MULTIPOINT ((4 6), (6 6), (6 8))"));
 }
 
 
-} // namespace tut
\ No newline at end of file
+} // namespace tut
