@@ -36,7 +36,7 @@ void object::test<1>
 ()
 {
     geom1_ = GEOSGeomFromWKT("LINESTRING(0 0, 1 0, 1 1)");
-    int r = GEOSisRing(geom1_);
+    char r = GEOSisRing(geom1_);
     ensure_equals(r, 0);
 }
 
@@ -46,7 +46,7 @@ void object::test<2>
 ()
 {
     geom1_ = GEOSGeomFromWKT("LINESTRING (0 0, 1 0, 1 1, 0 0)");
-    int r = GEOSisRing(geom1_);
+    char r = GEOSisRing(geom1_);
     ensure_equals(r, 1);
 }
 
@@ -56,7 +56,7 @@ void object::test<3>
 ()
 {
     geom1_ = GEOSGeomFromWKT("POINT (1 1)");
-    int r = GEOSisRing(geom1_);
+    char r = GEOSisRing(geom1_);
     ensure_equals(r, 0);
 }
 
@@ -66,7 +66,7 @@ void object::test<4>
 ()
 {
     geom1_ = GEOSGeomFromWKT("MULTILINESTRING ((0 0, 1 0, 1 1, 0 0))");
-    int r = GEOSisRing(geom1_);
+    char r = GEOSisRing(geom1_);
     ensure_equals(r, 0);
 }
 
@@ -76,9 +76,21 @@ void object::test<5>
 ()
 {
     geom1_ = GEOSGeomFromWKT("LINESTRING EMPTY");
-    int r = GEOSisRing(geom1_);
+    char r = GEOSisRing(geom1_);
     ensure_equals(r, 0);
 }
 
 
+template<>
+template<>
+void object::test<6>
+()
+{
+    geom1_ = GEOSGeomFromWKT("COMPOUNDCURVE (CIRCULARSTRING (0 0, 1 1, 2 0), (2 0, 0 0))");
+    ensure(geom1_);
+
+    char r = GEOSisRing(geom1_);
+    ensure_equals("curved geometetries not supported", r, 2);
+}
+
 } // namespace tut
