@@ -32,4 +32,15 @@ void object::test<2>()
     ensure_equals(0, GEOSisSimple(input_));
 }
 
+template<>
+template<>
+void object::test<3>()
+{
+    input_ = fromWKT("CIRCULARSTRING (0 0, 1 1, 2 0)");
+    ensure(input_ != nullptr);
+
+    char ret = GEOSisSimple(input_);
+    ensure_equals("error raised on curved geometry", ret, 2);
+}
+
 } // namespace tut
