@@ -7,15 +7,17 @@
 // geos
 #include <geos/geom/LineString.h>
 #include <geos/geom/Coordinate.h>
-#include <geos/geom/CoordinateArraySequence.h>
+#include <geos/geom/CoordinateSequence.h>
 #include <geos/geom/Dimension.h>
 #include <geos/geom/Geometry.h>
 #include <geos/geom/GeometryFactory.h>
 #include <geos/geom/PrecisionModel.h>
 #include <geos/io/WKTReader.h>
+#include <geos/io/WKTWriter.h>
 #include <geos/util/GEOSException.h>
 #include <geos/util/IllegalArgumentException.h>
 #include <geos/constants.h>
+#include <geos/util.h>
 // std
 #include <string>
 #include <cmath>
@@ -34,22 +36,27 @@ struct test_linestring_data {
     geos::geom::PrecisionModel pm_;
     geos::geom::GeometryFactory::Ptr factory_;
     geos::io::WKTReader reader_;
+    geos::io::WKTWriter writer_;
 
-    LineStringPtr empty_line_;
+    std::unique_ptr<geos::geom::LineString> empty_line_;
+    std::unique_ptr<geos::geom::LineString> line_;
 
     test_linestring_data()
         : pm_(1000)
         , factory_(geos::geom::GeometryFactory::create(&pm_, 0))
         , reader_(factory_.get())
-        , empty_line_(factory_->createLineString(new geos::geom::CoordinateArraySequence()))
+        , empty_line_(factory_->createLineString())
     {
         assert(nullptr != empty_line_);
+
+        auto cs = geos::detail::make_unique<geos::geom::CoordinateSequence>(2u, false, false);
+        cs->setAt(geos::geom::Coordinate{0, 0}, 0);
+        cs->setAt(geos::geom::Coordinate{1, 1}, 1);
+        line_ = factory_->createLineString(std::move(cs));
     }
 
     ~test_linestring_data()
     {
-        factory_->destroyGeometry(empty_line_);
-        empty_line_ = nullptr;
     }
 };
 
@@ -71,11 +78,11 @@ void object::test<1>
     using geos::geom::Coordinate;
 
     // Empty sequence of coordinates
-    CoordArrayPtr pseq = new geos::geom::CoordinateArraySequence();
+    auto pseq = geos::detail::make_unique<geos::geom::CoordinateSequence>();
     ensure("sequence is null pointer.", pseq != nullptr);
 
     // Create empty linstring instance
-    LineStringAutoPtr ls(factory_->createLineString(pseq));
+    auto ls = factory_->createLineString(std::move(pseq));
 
     ensure(ls->isEmpty());
     ensure(ls->isSimple());
@@ -93,7 +100,7 @@ void object::test<2>
     // Non-empty sequence of coordinates
     const std::size_t size3 = 3;
 
-    CoordArrayPtr pseq = new geos::geom::CoordinateArraySequence();
+    auto pseq = geos::detail::make_unique<geos::geom::CoordinateSequence>();
     ensure("sequence is null pointer.", pseq != nullptr);
 
     pseq->add(Coordinate(0, 0, 0));
@@ -103,7 +110,7 @@ void object::test<2>
     ensure_equals(pseq->size(), size3);
 
     // Create non-empty LineString instance
-    LineStringAutoPtr ls(factory_->createLineString(pseq));
+    auto ls = factory_->createLineString(std::move(pseq));
 
     ensure(!ls->isEmpty());
     ensure(ls->isSimple());
@@ -141,15 +148,14 @@ void object::test<3>
 ()
 {
     // Single-element sequence of coordinates
-    CoordArrayPtr pseq = nullptr;
     try {
-        pseq = new geos::geom::CoordinateArraySequence();
+        auto pseq = geos::detail::make_unique<CoordinateSequence>();
         ensure("sequence is null pointer.", pseq != nullptr);
         pseq->add(geos::geom::Coordinate(0, 0, 0));
         ensure_equals(pseq->size(), 1u);
 
         // Create incomplete LineString
-        LineStringAutoPtr ls(factory_->createLineString(pseq));
+        auto ls= factory_->createLineString(std::move(pseq));
         fail("IllegalArgumentException expected.");
     }
     catch(geos::util::IllegalArgumentException const& e) {
@@ -173,7 +179,7 @@ void object::test<4>
     // Non-empty sequence of coordinates
     const std::size_t size = 3;
 
-    CoordArrayPtr pseq = new geos::geom::CoordinateArraySequence();
+    auto pseq = geos::detail::make_unique<CoordinateSequence>();
     ensure("sequence is null pointer.", pseq != nullptr);
 
     pseq->add(Coordinate(0, 0, 0));
@@ -183,12 +189,12 @@ void object::test<4>
     ensure_equals(pseq->size(), size);
 
     // Create example of LineString instance
-    LineStringAutoPtr examplar(factory_->createLineString(pseq));
+    auto examplar = factory_->createLineString(std::move(pseq));
 
     // Create copy
-    LineStringAutoPtr copy(dynamic_cast<geos::geom::LineString*>(examplar->clone().release()));
+    auto copy = examplar->clone();
 
-    ensure(nullptr != copy.get());
+    ensure(nullptr != copy);
 
     ensure(!copy->isEmpty());
     ensure(copy->isSimple());
@@ -508,7 +514,7 @@ template<>
 void object::test<28>
 ()
 {
-    std::unique_ptr<geos::geom::Geometry> geo(reader_.read("LINESTRING (0 0, 10 10, 20 0))"));
+    std::unique_ptr<geos::geom::Geometry> geo(reader_.read("LINESTRING (0 0, 10 10, 20 0)"));
 
     ensure(geo->isDimensionStrict(geos::geom::Dimension::L));
     ensure(!geo->isDimensionStrict(geos::geom::Dimension::A));
@@ -552,7 +558,7 @@ void object::test<31>
     // Non-empty sequence of coordinates
     const std::size_t size3 = 3;
 
-    CoordArrayPtr pseq = new geos::geom::CoordinateArraySequence();
+    auto pseq = geos::detail::make_unique<CoordinateSequence>();
     ensure("sequence is null pointer.", pseq != nullptr);
 
     pseq->add(Coordinate(0, geos::DoubleNotANumber));
@@ -562,7 +568,7 @@ void object::test<31>
 
     try {
         // Create non-empty LineString instance
-        auto lr(factory_->createLinearRing(pseq));
+        auto lr(factory_->createLinearRing(std::move(pseq)));
         ensure(!lr->isEmpty());
         fail("IllegalArgumentException expected.");
     }
@@ -573,6 +579,34 @@ void object::test<31>
 
 }
 
+// Test of hasDimension()
+template<>
+template<>
+void object::test<32>
+()
+{
+    ensure(!line_->hasDimension(geos::geom::Dimension::P));
+    ensure(line_->hasDimension(geos::geom::Dimension::L));
+    ensure(!line_->hasDimension(geos::geom::Dimension::A));
+}
+
+
+// https://github.com/libgeos/geos/issues/1191
+// line->getPoint(n) loses M dimension
+template<>
+template<>
+void object::test<33>
+()
+{
+    auto geom = reader_.read("LINESTRING M (0 1 2, 10 11 12, 20 21 22)");
+    ensure(geom != nullptr);
+    geos::geom::LineString *line = static_cast<LineString*>(geom.get());
+    ensure_equals(line->getCoordinateDimension(), 3);
+    auto pt = line->getPointN(2);
+    auto out = writer_.write(*pt);
+    ensure_equals(out, "POINT M (20 21 22)");
+}
+
 
 } // namespace tut
 
