@@ -33,6 +33,10 @@
 namespace tut
 {
 
+template<class T>
+void
+ignore_unused_variable_warning(T const &) {}
+
 template <class, int>
 class test_group;
 
@@ -107,7 +111,7 @@ public:
      */
     bool called_method_was_a_dummy_test_;
 
-    virtual ~test_object()
+    ~test_object() override
     {
     }
 
@@ -145,7 +149,7 @@ struct tests_registerer<Test, Group, 0>
  * each new test since we have to have reinitialized
  * Data base class.
  */
-template <class Data, int MaxTestsInGroup = 50>
+template <class Data, int MaxTestsInGroup = 100>
 class test_group : public group_base, public test_group_posix
 {
     test_group(const test_group&);
@@ -188,7 +192,7 @@ class test_group : public group_base, public test_group_posix
 
     public:
         safe_holder()
-            : p_(0),
+            : p_(nullptr),
               permit_throw_in_dtor(false)
         {
         }
@@ -222,7 +226,7 @@ class test_group : public group_base, public test_group_posix
          * Specially treats exceptions in test object destructor;
          * if test itself failed, exceptions in destructor
          * are ignored; if test was successful and destructor failed,
-         * warning exception throwed.
+         * warning exception thrown.
          */
         void release()
         {
@@ -236,6 +240,7 @@ class test_group : public group_base, public test_group_posix
                 }
 #else
                 bool d = delete_obj();
+                ignore_unused_variable_warning(d);
                 assert(d && "delete failed with SEH disabled: runtime bug?");
 #endif
             }
@@ -276,7 +281,7 @@ class test_group : public group_base, public test_group_posix
             {
 #endif
                 T* p = p_;
-                p_ = 0;
+                p_ = nullptr;
                 delete p;
 #if defined(TUT_USE_SEH)
             }
@@ -338,7 +343,7 @@ public:
     /**
      * Reset test position before first test.
      */
-    void rewind()
+    void rewind() override
     {
         current_test_ = tests_.begin();
     }
@@ -346,7 +351,7 @@ public:
     /**
      * Runs next test.
      */
-    bool run_next(test_result &tr)
+    bool run_next(test_result &tr) override
     {
         if (current_test_ == tests_.end())
         {
@@ -371,7 +376,7 @@ public:
     /**
      * Runs one test by position.
      */
-    bool run_test(int n, test_result &tr)
+    bool run_test(int n, test_result &tr) override
     {
         if (tests_.rbegin() == tests_.rend() ||
             tests_.rbegin()->first < n)
@@ -379,7 +384,7 @@ public:
             return false;
         }
 
-        // withing scope; check if given test exists
+        // within scope; check if given test exists
         tests_iterator ti = tests_.find(n);
         if (ti == tests_.end())
         {
@@ -470,7 +475,7 @@ public:
         __try
         {
 #endif
-            if (obj.get() == 0)
+            if (obj.get() == nullptr)
             {
                 reset_holder_(obj);
             }
